| Title: | Data Sets for Keith McNulty's Handbook of Graphs and Networks in People Analytics |
|---|---|
| Description: | Data sets for network analysis related to People Analytics. Contains various data sets from the book 'Handbook of Graphs and Networks in People Analytics' by Keith McNulty (2021). |
| Authors: | Keith McNulty [aut, cre] (ORCID: <https://orcid.org/0000-0002-2332-1654>) |
| Maintainer: | Keith McNulty <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.9000 |
| Built: | 2026-05-12 06:18:58 UTC |
| Source: | https://github.com/keithmcnulty/onadata |
Network edgelist data as at the end of the Operation Caviar investigation into drug trafficking in Canada
caviar_endcaviar_end
A dataframe with 72 rows and 3 variables:
An individual under surveillance
An individual under surveillance
The number of intercepted communications between the individuals
caviar_endcaviar_end
Network edgelist data as at the middle of the Operation Caviar investigation into drug trafficking in Canada
caviar_middlecaviar_middle
A dataframe with 50 rows and 3 variables:
An individual under surveillance
An individual under surveillance
The number of intercepted communications between the individuals
caviar_middlecaviar_middle
Network edgelist data as at the start of the Operation Caviar investigation into drug trafficking in Canada
caviar_startcaviar_start
A dataframe with 26 rows and 3 variables:
An individual under surveillance
An individual under surveillance
The number of intercepted communications between the individuals
caviar_startcaviar_start
Extract of data on customers of a music sales company
chinook_customerschinook_customers
A dataframe with 59 rows and 4 variables:
Customer ID number
Customer First Name
Customer Last Name
ID of Sales Rep assigned to customer
chinook_customerschinook_customers
Extract of data on employees of a music sales company
chinook_employeeschinook_employees
A dataframe with 8 rows and 4 variables:
Employee ID number
Employee First Name
Employee Last Name
ID of Employee who they report to
chinook_employeeschinook_employees
Extract of data on customer invoices from a music sales company
chinook_invoiceschinook_invoices
A dataframe with 412 rows and 2 variables:
Invoice ID number
CustomerID number
chinook_invoiceschinook_invoices
Extract of data on items sold by a music sales company
chinook_itemschinook_items
A dataframe with 2240 rows and 2 variables:
ID number of invoice containing the item
ID number of the item
chinook_itemschinook_items
Edgelist of network of frequent interaction between bottlenose dolphins in Doubtful Sound, New Zealand
dolphinsdolphins
A dataframe with 159 rows and 2 variables:
Dolphin ID
Dolphin ID
dolphinsdolphins
Edgelist of network of email communications at a large European research institution
email_edgelistemail_edgelist
A dataframe with 24929 rows and 2 variables:
ID of sender
ID of receiver
email_edgelistemail_edgelist
Vertex data of network of email communications at a large European research institution
email_verticesemail_vertices
A dataframe with 1005 rows and 2 variables:
Vertex ID of individual
Department of individual
email_verticesemail_vertices
Data on voting in the UK EU membership referendum in 2016
eu_referendumeu_referendum
A dataframe with 382 rows and 4 variables:
UK Region
UK Area Code
Number of votes to remain in the EU
Number of votes to leave the EU
eu_referendumeu_referendum
Edgelist of network of characters of US TV Show Friends based on appearing in the same scene
friends_tv_edgelistfriends_tv_edgelist
A dataframe with 2976 rows and 3 variables:
Friends character
Friends character
Number of scenes with both characters
friends_tv_edgelistfriends_tv_edgelist
Edgelist of small network of 14 vertices
g14_edgelistg14_edgelist
A dataframe with 18 rows and 3 variables:
Vertex ID
Vertex ID
Edge weight
g14_edgelistg14_edgelist
Edgelist of network of social interactions between members of a karate club
karatekarate
A dataframe with 78 rows and 2 variables:
Member ID
Member ID
karatekarate
Edgelist of network of places connected by bridges in the city of Koenigsberg
koenigsbergkoenigsberg
A dataframe with 7 rows and 2 variables:
Place name
Place name
koenigsbergkoenigsberg
Edgelist of network of characters in Victor Hugo's Les Miserables based on appearance in the same chapter
lesmislesmis
A dataframe with 254 rows and 3 variables:
Character name
Character name
Number of chapters both characters appear in
lesmislesmis
Edgelist of network of London Tube/Underground stations
londontube_edgelistlondontube_edgelist
A dataframe with 406 rows and 4 variables:
Station ID
Station ID
Name of line connecting stations
Official color of line connecting stations
londontube_edgelistlondontube_edgelist
Vertices of network of London Tube/Underground stations
londontube_verticeslondontube_vertices
A dataframe with 302 rows and 4 variables:
Station ID
Station name
Station latitude
Station longitude
londontube_verticeslondontube_vertices
Edgelist of network of romantic relationships between characters of the TV show Mad Men
madmen_edgesmadmen_edges
A dataframe with 39 rows and 3 variables:
Character name
Character name
Whether the relationship was part of a marriage
madmen_edgesmadmen_edges
Vertices of network of romantic relationships between characters of the TV show Mad Men
madmen_verticesmadmen_vertices
A dataframe with 45 rows and 3 variables:
Character name
Character gender
Whether the character is a main character
madmen_verticesmadmen_vertices
Edgelist of network of academic collaboration between network scientists
netsciencenetscience
A dataframe with 2742 rows and 3 variables:
Scientist name
Scientist name
Measure of strength of collaboration
netsciencenetscience
Edgelist of Twitter interaction network of Ontario province politicians
ontariopol_edgelistontariopol_edgelist
A dataframe with 6095 rows and 3 variables:
Politician ID
Politician ID
Number of Twitter interactions
ontariopol_edgelistontariopol_edgelist
Vertices of Twitter interaction network of Ontario province politicians
ontariopol_verticesontariopol_vertices
A dataframe with 108 rows and 4 variables:
Politician ID
Politician Twitter screen name
Politician name
Party affiliation
ontariopol_verticesontariopol_vertices
Data on Yelp reviews of dog parks in Phoenix, AZ
park_reviewspark_reviews
A dataframe with 231 rows and 4 variables:
Park ID
User ID
Park name
Number of stars awarded by user
park_reviewspark_reviews
Data on altruistic acts by Reddit users fulfiling random requests for pizza
pizzapizza
A dataframe with 400 rows and 5 variables:
ID of the requester
ID of the individual who responded by ordering pizza for the requester
ID of the request
Number of Reddit votes made by the requester
Number of subreddits which the requester is a member of
pizzapizza
Edgelist of friend network of teenage girls in Scotland
s50_edgess50_edges
A dataframe with 122 rows and 2 variables:
Person ID
Person ID
s50_edgess50_edges
Vertices of friend network of teenage girls in Scotland
s50_verticess50_vertices
A dataframe with 50 rows and 5 variables:
Person ID
Frequency of smoking from 1 (Never) to 3 (Regularly)
Frequency of drinking alcohol from 1 (Never) to 5 (More than once a week)
Frequency of cannabis use from 1 (Never) to 4 (Regularly)
Frequency of sporting activity from 1 (Not regularly) to 2 (Regularly)
s50_verticess50_vertices
Edgelist of network of schoolfriends in a French high school
schoolfriends_edgelistschoolfriends_edgelist
A dataframe with 2105 rows and 3 variables:
Person ID
Person ID
Whether the friendship is a known Facebook connection or if it was reported by from person
schoolfriends_edgelistschoolfriends_edgelist
Vertices of network of schoolfriends in a French high school
schoolfriends_verticesschoolfriends_vertices
A dataframe with 329 rows and 3 variables:
Person ID
School class of person
Gender of person
schoolfriends_verticesschoolfriends_vertices
Edgelist of network of votes for Wikipedia administrators
wikivotewikivote
A dataframe with 103688 rows and 2 variables:
ID of voter
ID of vote recipient
wikivotewikivote
Edgelist of network of interactions between people in a French office building based on location sensor technology
workfrance_edgelistworkfrance_edgelist
A dataframe with 932 rows and 3 variables:
Person ID
Person ID
Number of minutes spent co-located
workfrance_edgelistworkfrance_edgelist
Vertices of network of interactions between people in a French office building based on location sensor technology
workfrance_verticesworkfrance_vertices
A dataframe with 211 rows and 2 variables:
Person ID
Department of person
workfrance_verticesworkfrance_vertices